@@ -62,7 +62,29 @@ class litleBatchRequest:
         self._batchRequest.numEcheckCredit = 0
         self._batchRequest.echeckCreditAmount = 0
         self._batchRequest.numEcheckRedeposit = 0
+        self._batchRequest.numEcheckPreNoteSale = 0
+        self._batchRequest.numEcheckPreNoteCredit = 0
+        self._batchRequest.numSubmerchantCredit = 0
+        self._batchRequest.submerchantCreditAmount = 0
         self._batchRequest.numEcheckSales = 0
+        self._batchRequest.numSubmerchantDebit = 0
+        self._batchRequest.submerchantDebitAmount = 0
+        self._batchRequest.numReserveCredit = 0
+        self._batchRequest.reserveCreditAmount = 0
+        self._batchRequest.numReserveDebit = 0
+        self._batchRequest.reserveDebitAmount = 0
+        self._batchRequest.numPayFacCredit = 0
+        self._batchRequest.payFacCreditAmount = 0
+        self._batchRequest.numPayFacDebit = 0
+        self._batchRequest.payFacDebitAmount = 0
+        self._batchRequest.numPhysicalCheckDebit = 0
+        self._batchRequest.physicalCheckDebitAmount = 0
+        self._batchRequest.numPhysicalCheckCredit = 0
+        self._batchRequest.physicalCheckCreditAmount = 0
+        self._batchRequest.numVendorDebit = 0
+        self._batchRequest.vendorDebitAmount = 0
+        self._batchRequest.numVendorCredit = 0
+        self._batchRequest.vendorCreditAmount = 0
         self._batchRequest.echeckSalesAmount = 0
         self._batchRequest.numUpdateCardValidationNumOnTokens = 0
         self._batchRequest.numAccountUpdates = 0
@@ -79,7 +101,7 @@ class litleBatchRequest:
         self._batchRequest.numUnloads = 0
         self._batchRequest.unloadAmount = 0
         self._batchRequest.numBalanceInquirys = 0
-        self._batchRequest.merchantSdk = '8.29.1'
+        self._batchRequest.merchantSdk = None
 
         __tmpDir = self.config.batchRequestFolder+'/tmp'
         self._maxTransactionsPerBatch = int(getattr(self.config, 'maxTransactionsPerBatch', '10000'))
@@ -175,18 +197,88 @@ class litleBatchRequest:
             self._batchRequest.numEcheckRedeposit += 1
             __transactionAdded = True
             self.numOfTxn += 1
+            
+        elif isinstance(transaction, litleXmlFields.echeckPreNoteSale.typeDefinition()):
+            self._batchRequest.numEcheckPreNoteSale += 1
+            __transactionAdded = True
+            self.numOfTxn += 1
+            
+        elif isinstance(transaction, litleXmlFields.echeckPreNoteCredit.typeDefinition()):
+            self._batchRequest.numEcheckPreNoteCredit += 1
+            __transactionAdded = True
+            self.numOfTxn += 1
 
         elif isinstance(transaction, litleXmlFields.echeckSale.typeDefinition()):
             self._batchRequest.numEcheckSales += 1
             self._batchRequest.echeckSalesAmount += transaction.amount
             __transactionAdded = True
             self.numOfTxn += 1
+            
+        elif isinstance(transaction, litleXmlFields.submerchantCredit.typeDefinition()):
+            self._batchRequest.numSubmerchantCredit += 1
+            self._batchRequest.submerchantCreditAmount += transaction.amount
+            __transactionAdded = True
+            self.numOfTxn += 1
+            
+        elif isinstance(transaction, litleXmlFields.submerchantDebit.typeDefinition()):
+            self._batchRequest.numSubmerchantDebit += 1
+            self._batchRequest.submerchantDebitAmount += transaction.amount
+            __transactionAdded = True
+            self.numOfTxn += 1
+            
+        elif isinstance(transaction, litleXmlFields.payFacCredit.typeDefinition()):
+            self._batchRequest.numPayFacCredit += 1
+            self._batchRequest.payFacCreditAmount += transaction.amount
+            __transactionAdded = True
+            self.numOfTxn += 1
+            
+        elif isinstance(transaction, litleXmlFields.payFacDebit.typeDefinition()):
+            self._batchRequest.numPayFacDebit += 1
+            self._batchRequest.payFacDebitAmount += transaction.amount
+            __transactionAdded = True
+            self.numOfTxn += 1
+            
+        elif isinstance(transaction, litleXmlFields.reserveCredit.typeDefinition()):
+            self._batchRequest.numReserveCredit += 1
+            self._batchRequest.reserveCreditAmount += transaction.amount
+            __transactionAdded = True
+            self.numOfTxn += 1
+            
+        elif isinstance(transaction, litleXmlFields.reserveDebit.typeDefinition()):
+            self._batchRequest.numReserveDebit += 1
+            self._batchRequest.reserveDebitAmount += transaction.amount
+            __transactionAdded = True
+            self.numOfTxn += 1
+            
+        elif isinstance(transaction, litleXmlFields.vendorCredit.typeDefinition()):
+            self._batchRequest.numVendorCredit += 1
+            self._batchRequest.vendorCreditAmount += transaction.amount
+            __transactionAdded = True
+            self.numOfTxn += 1
+            
+        elif isinstance(transaction, litleXmlFields.vendorDebit.typeDefinition()):
+            self._batchRequest.numVendorDebit += 1
+            self._batchRequest.vendorDebitAmount += transaction.amount
+            __transactionAdded = True
+            self.numOfTxn += 1
+            
+        elif isinstance(transaction, litleXmlFields.physicalCheckCredit.typeDefinition()):
+            self._batchRequest.numPhysicalCheckCredit += 1
+            self._batchRequest.physicalCheckCreditAmount += transaction.amount
+            __transactionAdded = True
+            self.numOfTxn += 1
+            
+        elif isinstance(transaction, litleXmlFields.physicalCheckDebit.typeDefinition()):
+            self._batchRequest.numPhysicalCheckDebit += 1
+            self._batchRequest.physicalCheckDebitAmount += transaction.amount
+            __transactionAdded = True
+            self.numOfTxn += 1
 
         elif isinstance(transaction, litleXmlFields.updateCardValidationNumOnToken.typeDefinition()):
             self._batchRequest.numUpdateCardValidationNumOnTokens += 1
             __transactionAdded = True
             self.numOfTxn += 1
-
+            
         elif isinstance(transaction, litleXmlFields.updateSubscription.typeDefinition()):
             self._batchRequest.numUpdateSubscriptions += 1
             __transactionAdded = True
@@ -287,10 +379,10 @@ class litleBatchFileRequest:
 
         if config is None:
             self.config = Configuration()
+            self.config.printXml = None
         confParser = ConfigParser()
 
         configFilePath = self.config.configFolder + '/' + self.config.getConfigFileName()
-
         if not os.path.exists(configFilePath):
             f = open(configFilePath, 'a')
             f.close()
@@ -305,6 +397,9 @@ class litleBatchFileRequest:
         for prop in propertyList:
             if confParser.has_option('PythonSDK', prop) and not hasattr(self.config, prop):
                 setattr(self.config, prop, confParser.get('PythonSDK', prop))
+        
+        if confParser.has_option('PythonSDK', 'printXml') and hasattr(self.config, 'printXml') and self.config.printXml == None :
+            setattr(self.config, 'printXml', confParser.get('PythonSDK','printXml'))
 
         self.communication = Communications(self.config)
 
@@ -387,7 +482,7 @@ class litleBatchFileRequest:
             litleRequest.id = self.requestId
 
         litleRequest.authentication = authentication
-        litleRequest.version = '8.29'
+        litleRequest.version = '9.3'
         litleRequest.numBatchRequests = len(self.batchRequestList)
         requestFile = open(self.requestFile.name,'wb')
         requestFile.write(self.tnxToXml(litleRequest).replace('</litleRequest>', ''))
