@@ -25,7 +25,6 @@
 import litleXmlFields
 import pyxb
 import os
-import re
 from Communications import *
 from Configuration import *
 
@@ -43,10 +42,7 @@ class litleOnlineRequest:
     def _litleToXml(self,litleOnline):
         try :
             dom = litleOnline.toDOM()
-            #dom = dom.toprettyxml()
-            temp = dom.toprettyxml(encoding='utf-8', indent="  ")
-            text_re = re.compile('>\n\s+([^<>\s].*?)\n\s+</', re.DOTALL)    
-            temp = text_re.sub('>\g<1></', temp)
+            temp = dom.toxml('utf-8')
             temp= temp.replace('ns1:','')
             return temp.replace(':ns1','')
         except pyxb.BindingValidationError,e:
@@ -79,8 +75,8 @@ class litleOnlineRequest:
     def _createTxn(self, transaction):
         litleOnline = litleXmlFields.litleOnlineRequest()
         litleOnline.merchantId = self.MerchantId
-        litleOnline.version = '8.29'
-        litleOnline.merchantSdk = '8.29.1'
+        litleOnline.version = '9.3'
+        litleOnline.merchantSdk = '9.3.1'
         authentication = litleXmlFields.authentication()
         authentication.user = self.User
         authentication.password =  self.Password 
